@@ -34,9 +34,11 @@
 #include <KMessageBox>
 #include <KParts/MainWindow>
 #include <KConfigGroup>
+#include <QFileInfo>
 
 #include <QDebug>
 #include "debuggerdebug.h"
+#include <util/environmentprofilelist.h>
 
 
 namespace Python {
@@ -78,7 +80,7 @@ KJob* PdbLauncher::start(const QString& launchMode, KDevelop::ILaunchConfigurati
         
         // check the interpreter
         QProcess p;
-        p.setReadChannelMode(QProcess::MergedChannels);
+        p.setProcessChannelMode(QProcess::MergedChannels);
         p.start(interpreter, QStringList() << "--version");
         p.waitForFinished(500);
         QByteArray version = p.readAll();
@@ -103,11 +105,29 @@ KJob* PdbLauncher::start(const QString& launchMode, KDevelop::ILaunchConfigurati
             scriptUrl = iface->script(cfg, err);
         }
 
+        auto wd = iface->workingDirectory(cfg);
+        if( !wd.isValid() || wd.isEmpty() )
+        {
+            wd = QUrl::fromLocalFile( QFileInfo( scriptUrl.toLocalFile() ).absolutePath() );
+        }
+
         DebugJob* job = new DebugJob();
         job->m_scriptUrl = scriptUrl;
         job->m_interpreter = interpreter;
         job->m_args = iface->arguments(cfg, err);
-        job->m_workingDirectory = iface->workingDirectory(cfg);
+        job->m_workingDirectory = wd;
+
+        const KDevelop::EnvironmentProfileList environmentProfiles(KSharedConfig::openConfig());
+        QString envProfileName = iface->environmentProfileName(cfg);
+
+        if (envProfileName.isEmpty()) {
+            qCWarning(KDEV_PYTHON_DEBUGGER) << "No environment profile specified, looks like a broken "
+                                       "configuration, please check run configuration " << cfg->name() <<
+                                       ". Using default environment profile.";
+            envProfileName = environmentProfiles.defaultProfileName();
+        }
+        job->m_envProfileName = envProfileName;
+
         QList<KJob*> l;
         l << job;
         return new KDevelop::ExecuteCompositeJob( KDevelop::ICore::self()->runController(), l );
