@@ -131,6 +131,7 @@ public:
         SliceAstType,
         EllipsisAstType,
         IndexAstType,
+        AssignmentExpressionAstType,
         LastExpressionType, // keep this at the end of the expr ast list
 
         CodeAstType,
@@ -243,16 +244,6 @@ public:
 class KDEVPYTHONPARSER_EXPORT Identifier : public Ast {
 public:
     Identifier(QString value);
-    Identifier operator=(const Identifier& other) {
-        value = other.value;
-        startCol = other.startCol;
-        endCol = other.endCol;
-        startLine = other.startLine;
-        endLine = other.endLine;
-        parent = other.parent;
-        hasUsefulRangeInformation = other.hasUsefulRangeInformation;
-        return *this;
-    };
     bool operator==(const Identifier& rhs) const {
         return value == rhs.value;
     };
@@ -457,6 +448,13 @@ public:
     ExpressionAst* value; // WARNING this is not set in most cases!
 };
 
+class KDEVPYTHONPARSER_EXPORT AssignmentExpressionAst : public ExpressionAst {
+public:
+    AssignmentExpressionAst(Ast* parent);
+    ExpressionAst* target;
+    ExpressionAst* value;
+};
+
 class KDEVPYTHONPARSER_EXPORT AwaitAst : public ExpressionAst {
 public:
     AwaitAst(Ast* parent);
@@ -743,6 +741,7 @@ public:
     ArgumentsAst(Ast* parent);
     QList<ArgAst*> arguments;
     QList<ArgAst*> kwonlyargs;
+    QList<ArgAst*> posonlyargs;
     QList<ExpressionAst*> defaultValues;
     ArgAst* vararg;
     ArgAst* kwarg;
