@@ -63,7 +63,7 @@ public:
     KDevelop::ICodeHighlighting* codeHighlighting() const override;
     KDevelop::BasicRefactoring* refactoring() const override;
     
-    KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context) override;
+    KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context, QWidget* parent) override;
     
     static LanguageSupport* self();
 
